pub fn get_metric_for_name(name: &str) -> &'static MetricDataExpand description
Find a Font Metric for a given fontname, fallback to 10pt or cmr as needed. Perl: getMetricForName
pub fn get_metric_for_name(name: &str) -> &'static MetricDataFind a Font Metric for a given fontname, fallback to 10pt or cmr as needed. Perl: getMetricForName